@@ -141,22 +141,28 @@ func needUpdate(iface *sriovnetworkv1.Interface, ifaceStatus *sriovnetworkv1.Int
 	}
 	if iface.NumVfs > 0 {
 		for _, vf := range ifaceStatus.VFs {
-			for i := range iface.VfGroups {
-				if !sriovnetworkv1.IndexInRange(vf.VfID, iface.VfGroups[i].VfRange) {
-					if sriovnetworkv1.StringInArray(vf.Driver, DpdkDrivers) {
-						return true
-					}
-				}
-				if iface.VfGroups[i].DeviceType != "netdevice" {
-					if iface.VfGroups[i].DeviceType != vf.Driver {
-						return true
-					}
-				} else {
-					if sriovnetworkv1.StringInArray(vf.Driver, DpdkDrivers) {
-						return true
+			ingroup := false
+			for _, group := range iface.VfGroups {
+				if sriovnetworkv1.IndexInRange(vf.VfID, group.VfRange) {
+					ingroup = true
+					if group.DeviceType != "netdevice" {
+						if group.DeviceType != vf.Driver {
+							glog.V(2).Infof("needUpdate(): Driver needs update, desired=%s, current=%s", group.DeviceType, vf.Driver)
+							return true
+						}
+					} else {
+						if sriovnetworkv1.StringInArray(vf.Driver, DpdkDrivers) {
+							glog.V(2).Infof("needUpdate(): Driver needs update, desired=%s, current=%s", group.DeviceType, vf.Driver)
+							return true
+						}
 					}
+					break
 				}
 			}
+			if !ingroup && sriovnetworkv1.StringInArray(vf.Driver, DpdkDrivers) {
+				// VF which has DPDK driver loaded but not in any group, needs to be reset to default driver.
+				return true
+			}
 		}
 	}
 	return false
@@ -179,10 +185,12 @@ func configSriovDevice(iface *sriovnetworkv1.Interface, ifaceStatus *sriovnetwor
 		}
 	}
 	// set PF mtu
-	err = setNetdevMTU(iface.PciAddress, iface.Mtu)
-	if err != nil {
-		glog.Warningf("configSriovDevice(): fail to set mtu for PF %s: %v", iface.PciAddress, err)
-		return err
+	if iface.Mtu > 0 && iface.Mtu != ifaceStatus.Mtu {
+		err = setNetdevMTU(iface.PciAddress, iface.Mtu)
+		if err != nil {
+			glog.Warningf("configSriovDevice(): fail to set mtu for PF %s: %v", iface.PciAddress, err)
+			return err
+		}
 	}
 	// Config VFs
 	if iface.NumVfs > 0 {
